package com.jnssd.controller;

import com.jnssd.model.User;
import lombok.Data;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.PostMapping;

import java.util.Comparator;
import java.util.List;
import java.util.Objects;

/**
 * <h3>spring-boot-openapi</h3>
 * <p>用户</p>
 *
 * @author zxj
 * @since 2023-10-12 16:30:04
 */
@Data
public class UserController {

    final static String SUCCESS_TEXT = "操作成功！";
    final static String FAIL_TEXT = "操作失败！";

    List<User> list = new java.util.ArrayList<>();

    public ResponseEntity<List<User>> getAll() {
        return ResponseEntity.ok(list);
    }

    // 添加方法
    @PostMapping("add")
    public ResponseEntity<String> add(User entity) {
        try {
            entity.setId(Objects.requireNonNull(list.stream().max(Comparator.comparingInt(User::getId)).get()).getId() + 1);
            list.add(entity);
            return ResponseEntity.ok(SUCCESS_TEXT);
        } catch (Exception e) {
            return ResponseEntity.status(400).body(FAIL_TEXT);
        }
    }

    // 添加方法
    @PostMapping("update")
    public ResponseEntity<Object> update(User entity) {
        try {
            // 修改list下面的数据
            list.replaceAll((User) -> Objects.equals(User.getId(), entity.getId()) ? entity : User);

            return ResponseEntity.ok(SUCCESS_TEXT);
        } catch (Exception e) {
            return ResponseEntity.status(400).body(FAIL_TEXT);
        }
    }

    // 删除方法
    @PostMapping("delete")
    public ResponseEntity<String> delete(User entity) {
        try {
            boolean result = list.removeIf(e -> Objects.equals(e.getId(), entity.getId()));
            return result ? ResponseEntity.ok(SUCCESS_TEXT) : ResponseEntity.status(400).body(FAIL_TEXT);
        } catch (Exception e) {
            return ResponseEntity.status(400).body(null);
        }
    }

    // 查询方法
    @PostMapping("query")
    public ResponseEntity<Object> query(Integer id) {
        try {
            User User = (User) list.stream().filter(e -> Objects.equals(e.getId(), id));
            // list 下查询
            return ResponseEntity.ok(User);
        } catch (Exception e) {
            return ResponseEntity.status(400).body(FAIL_TEXT);
        }
    }
}
